@@ -1,5 +1,5 @@
 package Bot::Cobalt::Plugin::Calc::Worker;
-$Bot::Cobalt::Plugin::Calc::Worker::VERSION = '0.004003';
+$Bot::Cobalt::Plugin::Calc::Worker::VERSION = '0.004004';
 use strict;
 use bytes;
 
@@ -26,12 +26,12 @@ sub worker {
   select *STDOUT;
   $|++;
  
-  # not error-checked, may fail silently on some platforms ...
-  setrlimit(RLIMIT_DATA, MEMLIMIT_BYTES, MEMLIMIT_BYTES);
-  setrlimit(RLIMIT_STACK, MEMLIMIT_BYTES, MEMLIMIT_BYTES);
-  setrlimit(RLIMIT_AS, MEMLIMIT_BYTES, MEMLIMIT_BYTES);
-  setrlimit(RLIMIT_VMEM, MEMLIMIT_BYTES, MEMLIMIT_BYTES);
-  setrlimit(RLIMIT_CPU, 10, 10);
+  # not error-checked, may fail silently on some platforms ..
+  # (OpenBSD lacks RLIMIT_AS f.ex)
+  setrlimit RLIMIT_CPU, 10, 10;
+  for my $const (RLIMIT_DATA RLIMIT_STACK RLIMIT_AS RLIMIT_VMEM) {
+    eval {; setrlimit $const, MEMLIMIT_BYTES, MEMLIMIT_BYTES };
+  }
 
   my ($buf, $read_bytes) = '';
   while (1) {
